Computational Performance vs. Existing Pipelines
================================================

.. include:: ../../README.md
   :parser: markdown
   :start-after: Computational Performance vs. Existing Pipelines
   :end-before: XGBoost Model Performance on MIMIC-IV
